@@ -31,7 +31,7 @@
  *
  * The Initial Developer of the Original Code is Jan Willamowius.
  *
- * $Id: h235crypto.h,v 1.28 2014/01/02 13:15:41 shorne Exp $
+ * $Id: h235crypto.h,v 1.29 2014/11/18 14:40:08 willamowius Exp $
  *
  */
 
@@ -115,8 +115,6 @@ protected:
     PBoolean m_initialised;
 
     unsigned char m_iv[EVP_MAX_IV_LENGTH];
-    int m_inSize;
-    int m_outSize;
 
     int m_enc_blockSize;
     int m_enc_ivLength;
