@@ -23,7 +23,7 @@
  *
  * Contributor(s): Frbass Franz <franz.fuerbass@infonova.at>
  *
- * $Id: h235auth.h,v 1.31 2013/12/28 17:11:04 shorne Exp $
+ * $Id: h235auth.h,v 1.37 2017/01/30 05:14:00 shorne Exp $
  *
  */
 
@@ -86,14 +86,14 @@ class H235Authenticator : public PObject
     static H235Authenticator * CreateAuthenticatorByID(const PString & identifier
                                                  );
 
-    static PBoolean GetAuthenticatorCapabilities(const PString & deviceName,                 
-                                                Capabilities * caps, 
+    static PBoolean GetAuthenticatorCapabilities(const PString & deviceName,
+                                                Capabilities * caps,
                                                 PPluginManager * pluginMgr = NULL);
 #endif
 
 #ifdef H323_H235
-    
-    virtual PBoolean GetMediaSessionInfo(PString & algorithmOID, PBYTEArray & sessionKey); 
+
+    virtual PBoolean GetMediaSessionInfo(PString & algorithmOID, PBYTEArray & sessionKey);
 #endif
 
     virtual const char * GetName() const = 0;
@@ -158,15 +158,9 @@ class H235Authenticator : public PObject
 
     virtual PBoolean UseGkAndEpIdentifiers() const;
 
-    virtual PBoolean IsSecuredPDU(
-      unsigned rasPDU,
-      PBoolean received
-    ) const;
+    virtual PBoolean IsSecuredPDU(unsigned rasPDU, PBoolean received) const;
 
-    virtual PBoolean IsSecuredSignalPDU(
-      unsigned signalPDU,
-      PBoolean received
-    ) const;
+    virtual PBoolean IsSecuredSignalPDU(unsigned signalPDU, PBoolean received) const;
 
     virtual PBoolean IsSecuredSignalPDU(
       unsigned signalPDU,
@@ -176,10 +170,8 @@ class H235Authenticator : public PObject
 
     virtual PBoolean IsActive() const;
 
-    virtual void Enable(
-      PBoolean enab = TRUE
-    ) { enabled = enab; }
-    virtual void Disable() { enabled = FALSE; }
+    virtual void Enable(PBoolean enab = true) { enabled = enab; }
+    virtual void Disable() { enabled = false; }
 
     virtual const PString & GetRemoteId() const { return remoteId; }
     virtual void SetRemoteId(const PString & id) { remoteId = id; }
@@ -210,7 +202,7 @@ class H235Authenticator : public PObject
     virtual PBoolean GetAlgorithmDetails(const PString & algorithm,   ///< Algorithm OID
                                          PString & sslName,           ///< SSL Description
                                          PString & description        ///< Human Description
-                                         ); 
+                                         );
 
     virtual void ExportParameters(const PFilePath & /*path*/) {}  // export Parameters to file
 
@@ -223,7 +215,7 @@ class H235Authenticator : public PObject
       H225_ArrayOf_PASN_ObjectId & algorithmOIDs
     );
 
-    PBoolean     enabled;
+    PBoolean enabled;
 
     PString  remoteId;      // ID of remote entity
     PString  localId;       // ID of local entity
@@ -234,10 +226,9 @@ class H235Authenticator : public PObject
     unsigned lastTimestamp;
     int      timestampGracePeriod;
 
-    Application usage;	       ///* Authenticator's Application 
+    Application usage;	       ///* Authenticator's Application
     H323Connection * connection;   ///* CallToken of the Connection for EP Authentication
     PMutex mutex;
-
 };
 
 
@@ -280,6 +271,16 @@ PDECLARE_LIST(H235Authenticators, H235Authenticator)
     ) const;
 
 #ifdef H323_H235
+    struct DH_Data {
+        DH_Data() 
+         : m_gData(0) {};
+
+        PString     m_OID;
+        PBYTEArray  m_pData;
+        PBYTEArray  m_gData;
+    };
+    typedef list<DH_Data> DH_DataList;
+
     PBoolean CreateAuthenticators(const PASN_Array & clearTokens, const PASN_Array & cryptoTokens);
     PBoolean CreateAuthenticators(H235Authenticator::Application usage);
     PBoolean CreateAuthenticator(const PString & name);
@@ -304,6 +305,9 @@ PDECLARE_LIST(H235Authenticators, H235Authenticator)
     static PString & GetDHParameterFile();
     static void SetDHParameterFile(const PString & filePaths);
 
+    static void LoadDHData(const PString & oid, const PBYTEArray & pData, const PBYTEArray & gData);
+    static DH_DataList & GetDHDataList();
+
  protected:
     void CreateAuthenticatorsByID(const PStringArray & identifiers);
 
@@ -311,6 +315,7 @@ PDECLARE_LIST(H235Authenticators, H235Authenticator)
     static PINDEX m_cipherLength;
     static PINDEX m_maxTokenLength;
     static PString m_dhFile;
+    static DH_DataList m_dhData;
 #endif
 
 };
@@ -339,7 +344,36 @@ H323_DECLARELIST(H235AuthenticatorList, H235AuthenticatorInfo)
 };
 
 /** Dictionary of Addresses and Associated Security Info  */
-H323DICTIONARY(H235AuthenticatorDict,PString,H235AuthenticatorInfo); 
+H323DICTIONARY(H235AuthenticatorDict,PString,H235AuthenticatorInfo);
+
+
+/* This class is a device independent Time class that is used with H.235 Authentication mechanisms
+   It replaces the local time function to support remote gatekeeper synchronisation and ensures security
+   is not effected if the user changes the local device time while the application is running. */
+
+class H235AuthenticatorTime : public PObject
+{
+    PCLASSINFO(H235AuthenticatorTime, PObject);
+
+  public:
+    H235AuthenticatorTime();
+
+    /* GetLocalTime : Returns the local calculated time */
+    PUInt32b GetLocalTime();
+
+    /* GetTime : Returns the calculated synchronised time */
+    PUInt32b GetTime();
+
+    /* GetTime : Adjust the time to synchronise with remote time */
+    void SetAdjustedTime(time_t remoteTime);
+
+  protected:
+    time_t      m_localTimeStart;   ///< Local time at class instance.
+    clock_t     m_localStartTick;   ///< Local Tick count at class instance.
+    PInt64      m_adjustedTime;     ///< Adjusted time for remote synchronisation.
+
+};
+
 
 /** This class embodies a simple MD5 based authentication.
     The users password is concatenated with the 4 byte timestamp and 4 byte
@@ -392,7 +426,7 @@ class H235AuthSimpleMD5 : public H235Authenticator
 ////////////////////////////////////////////////////
 
 
-#if PTLIB_VER >= 2110 && defined(P_SSL)
+#if PTLIB_VER >= 2110
 /// PFactory Loader
 typedef H235AuthSimpleMD5 H235AuthenticatorMD5;
 #ifndef _WIN32_WCE
@@ -438,13 +472,10 @@ class H235AuthCAT : public H235Authenticator
       H225_ArrayOf_PASN_ObjectId & algorithmOIDs
     );
 
-    virtual PBoolean IsSecuredPDU(
-      unsigned rasPDU,
-      PBoolean received
-    ) const;
+    virtual PBoolean IsSecuredPDU(unsigned rasPDU, PBoolean received) const;
 };
 
-#if PTLIB_VER >= 2110 && defined(P_SSL)
+#if PTLIB_VER >= 2110
 // PFactory Loader
 typedef H235AuthCAT H235AuthenticatorCAT;
 #ifndef _WIN32_WCE
@@ -452,7 +483,55 @@ typedef H235AuthCAT H235AuthenticatorCAT;
 #endif
 #endif
 
+//////////////////////////////////////////////////////////////////////////////
 
+/** This class is used for Time Stamp Synchronisation between the gatekeeper
+    and the endpoint
+*/
+class H235AuthenticatorTSS : public H235Authenticator
+{
+    PCLASSINFO(H235AuthenticatorTSS, H235Authenticator);
+  public:
+    H235AuthenticatorTSS();
+
+    PObject * Clone() const;
+
+    virtual const char * GetName() const;
+
+    static PStringArray GetAuthenticatorNames();
+#if PTLIB_VER >= 2110
+    static PBoolean GetAuthenticationCapabilities(Capabilities * ids);
+#endif
+
+    virtual H235_ClearToken * CreateClearToken();
+
+    virtual ValidationResult ValidateClearToken(
+      const H235_ClearToken & clearToken
+    );
+
+    virtual PBoolean IsCapability(
+      const H235_AuthenticationMechanism & mechansim,
+      const PASN_ObjectId & algorithmOID
+    );
+
+    virtual PBoolean SetCapability(
+      H225_ArrayOf_AuthenticationMechanism & mechansim,
+      H225_ArrayOf_PASN_ObjectId & algorithmOIDs
+    );
+
+    virtual PBoolean IsSecuredPDU(
+      unsigned rasPDU,
+      PBoolean received
+    ) const;
+};
+
+#if PTLIB_VER >= 2110
+#ifndef _WIN32_WCE
+  PPLUGIN_STATIC_LOAD(TSS,H235Authenticator);
+#endif
+#endif
+
+//////////////////////////////////////////////////////////////////////////////
 #if H323_SSL
 
 /** This class embodies the H.235 "base line" from H235.1.
@@ -476,9 +555,7 @@ class H2351_Authenticator : public H235Authenticator
 
     virtual H225_CryptoH323Token * CreateCryptoToken();
 
-    virtual PBoolean Finalise(
-      PBYTEArray & rawPDU
-    );
+    virtual PBoolean Finalise(PBYTEArray & rawPDU);
 
     virtual ValidationResult ValidateCryptoToken(
       const H225_CryptoH323Token & cryptoToken,
@@ -495,21 +572,28 @@ class H2351_Authenticator : public H235Authenticator
       H225_ArrayOf_PASN_ObjectId & algorithmOIDs
     );
 
-    virtual PBoolean IsSecuredPDU(
-      unsigned rasPDU,
-      PBoolean received
-    ) const;
+    virtual PBoolean IsSecuredPDU(unsigned rasPDU, PBoolean received) const;
 
-    virtual PBoolean IsSecuredSignalPDU(
-      unsigned rasPDU,
-      PBoolean received
-    ) const;
+    virtual PBoolean IsSecuredSignalPDU(unsigned rasPDU, PBoolean received) const;
 
     virtual PBoolean UseGkAndEpIdentifiers() const;
+
+    virtual void RequireGeneralID(bool value) { m_requireGeneralID = value; }
+    virtual void CheckSendersID(bool value) { m_checkSendersID = value; }
+    virtual void FullQ931Checking(bool value) { m_fullQ931Checking = value; }
+    virtual void VerifyRandomNumber(bool value) { m_verifyRandomNumber = value; }
+
+protected:
+    PBoolean m_requireGeneralID;
+    PBoolean m_checkSendersID;
+    PBoolean m_fullQ931Checking;
+    PBoolean m_verifyRandomNumber;
 };
 
 typedef H2351_Authenticator H235AuthProcedure1;  // Backwards interoperability
 
+#endif
+
 //////////////////////////////////////////////////////////////////////////////
 
 #if PTLIB_VER >= 2130
@@ -531,12 +615,12 @@ template <class className> class H235PluginServiceDescriptor : public PDevicePlu
 {
   public:
     virtual PObject *   CreateInstance(int /*userData*/) const { return new className; }
-    virtual PStringArray GetDeviceNames(int /*userData*/) const { 
-               return className::GetAuthenticatorNames(); 
+    virtual PStringArray GetDeviceNames(int /*userData*/) const {
+               return className::GetAuthenticatorNames();
     }
-    virtual bool  ValidateDeviceName(const PString & deviceName, int /*userData*/) const { 
+    virtual bool  ValidateDeviceName(const PString & deviceName, int /*userData*/) const {
             return (deviceName == className::GetAuthenticatorNames()[0]);
-    } 
+    }
 #if PTLIB_VER >= 2110
     virtual bool GetDeviceCapabilities(const PString & /*deviceName*/, void * capabilities) const {
         return className::GetAuthenticationCapabilities((H235Authenticator::Capabilities *)capabilities);
@@ -546,9 +630,7 @@ template <class className> class H235PluginServiceDescriptor : public PDevicePlu
 
 #define H235SECURITY(name) \
 static H235PluginServiceDescriptor<H235Authenticator##name> H235Authenticator##name##_descriptor; \
-PCREATE_PLUGIN(name, H235Authenticator, &H235Authenticator##name##_descriptor); 
-#endif
-
+PCREATE_PLUGIN(name, H235Authenticator, &H235Authenticator##name##_descriptor);
 #endif
 
 
