@@ -36,7 +36,7 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Id: h46018_h225.h,v 1.41 2014/02/23 23:55:49 shorne Exp $
+ * $Id: h46018_h225.h,v 1.42 2014/11/27 02:27:07 shorne Exp $
  *
  */
 
@@ -748,6 +748,9 @@ private:
     WORD keepseqno;                            ///< KeepAlive sequence number
     PTime * keepStartTime;                    ///< KeepAlive start time for TimeStamp.
 
+    PThread * initialKeep;                    ///< Initial keepalive thread.
+    PDECLARE_NOTIFIER(PThread, H46019UDPSocket, StartKeepAlives); ///< First keep alives handling
+
     PDECLARE_NOTIFIER(PTimer, H46019UDPSocket, Ping);    ///< Timer to notify to poll for External IP
     PTimer    Keep;                                        ///< Polling Timer
 
