@@ -31,7 +31,7 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Id: h460_std23.h,v 1.18 2013/12/27 07:25:25 shorne Exp $
+ * $Id: h460_std23.h,v 1.21 2014/03/09 08:00:29 shorne Exp $
  *
  */
 
@@ -173,6 +173,7 @@ public:
     static PStringArray GetFeatureName() { return PStringArray("Std23"); };
     static PStringArray GetFeatureFriendlyName() { return PStringArray("P2Pnat Detect-H.460.23"); };
     static int GetPurpose()    { return FeatureRas; };
+    virtual int GetFeaturePurpose()  { return H460_FeatureStd23::GetPurpose(); } 
     static PStringArray GetIdentifier() { return PStringArray("23"); };
 
     virtual PBoolean CommonFeature() { return isEnabled; }
@@ -191,6 +192,7 @@ public:
     void OnNATTypeDetection(PSTUNClient::NatTypes type, const PIPSocket::Address & ExtIP);
 
     bool IsAvailable();
+    bool IsUDPAvailable();
 
     bool AlternateNATMethod();
     bool UseAlternate();
@@ -214,10 +216,6 @@ private:
     PBoolean                 isEnabled; 
     int                      useAlternate;
 
-    // Delayed Reregistration
-    PThread  *  RegThread;
-    PDECLARE_NOTIFIER(PThread, H460_FeatureStd23, RegMethod);
-
 };
 
 // Need to declare for Factory Loader
@@ -247,11 +245,11 @@ public:
     virtual void AttachEndPoint(H323EndPoint * _ep);
     virtual void AttachConnection(H323Connection * _ep);
 
-    static PStringArray GetFeatureName() { return PStringArray("Std24"); };
-    static PStringArray GetFeatureFriendlyName() { return PStringArray("P2Pnat Media-H.460.24"); };
-    static int GetPurpose()    { return FeatureSignal; };
-    static PStringArray GetIdentifier() { return PStringArray("24"); };
-
+    static PStringArray GetFeatureName() { return PStringArray("Std24"); }
+    static PStringArray GetFeatureFriendlyName() { return PStringArray("P2Pnat Media-H.460.24"); }
+    static int GetPurpose()    { return FeatureSignal; }
+    virtual int GetFeaturePurpose()  { return H460_FeatureStd24::GetPurpose(); } 
+    static PStringArray GetIdentifier() { return PStringArray("24"); }
     virtual PBoolean CommonFeature() { return isEnabled; }
 
     enum NatInstruct {
