@@ -26,7 +26,7 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Id: transports.h,v 1.24 2014/01/08 06:25:15 shorne Exp $
+ * $Id: transports.h,v 1.25 2014/02/20 08:37:08 shorne Exp $
  *
  */
 
@@ -636,6 +636,14 @@ class H323Transport : public PIndirectChannel
     /**Do SSL Accept handshake
       */
     virtual PBoolean SecureAccept() { return false; }
+
+   /**Whether the call has been established
+     */
+    virtual PBoolean IsCallEstablished() { return m_established; }
+
+    /**Set Call established
+     */
+    virtual void SetCallEstablished() { m_established = true; }
   //@}
 
   /**@name Member variable access */
@@ -677,6 +685,7 @@ class H323Transport : public PIndirectChannel
     PBoolean canGetInterface;
 
     PBoolean    m_secured;     /// Whether the channel is secure.
+    PBoolean    m_established; /// Whether the call is established.
 };
 
 
